/// <reference types="react" />
/**
 * Hook to sync single search param with the URL.
 *
 * Initialise the hook by providing the param-name (key)
 * and it will try to get the corresponding value from
 * the URL if available.
 *
 * Use setter function to update the value and same should
 * be reflected in the URL. Setting empty value will remove
 * the param from the URL.
 *
 * @param paramName Key used for referring the value.
 * @param fallbackParamValue Value assigned to param if not already set.
 * @returns [value, setValue]
 *
 * @example
 * ```
 * const [userId, setUserId] = useSearchParamState("userId");
 * ```
 */
export default function useSearchParamState(paramName: string, fallbackParamValue?: string | undefined | null): [string | null | undefined, import("react").Dispatch<import("react").SetStateAction<string | null | undefined>>];
